@@ -1,7 +1,7 @@
 
 # data is a raster.  grid is ignored
 setMethod("lgm", 
-  signature("formula", "Raster", "ANY", "ANY"),
+  signature("formula", "SpatRaster", "ANY", "ANY"),
   function(formula, data, grid, 
     covariates, 
     buffer=0,
@@ -16,13 +16,15 @@ setMethod("lgm",
     
     if(missing(covariates))
       covariates = list()
-    
+
+   
     dataCov = gm.dataRaster(
       formula, data,
-      grid=raster(data),
+      grid=rast(data, nlyrs=1),
       covariates=covariates,
       buffer=0)
     
+
     data=dataCov$data 
     grid=dataCov$grid 
     covariates=dataCov$covariates
@@ -43,7 +45,7 @@ setMethod("lgm",
 
 
 setMethod("lgm", 
-  signature("formula", "data.frame", "Raster", "data.frame"), 
+  signature("formula", "data.frame", "SpatRaster", "data.frame"), 
   function(formula, data, grid, 
     covariates, 
     buffer=0,
