@@ -153,7 +153,7 @@ profLlgm = function(fit,mc.cores=1, ...) {
           xout=res$breaks[Skeep],
           method= "hyman"), silent=TRUE)
       
-      if(class(resCi)!='try-error')
+      if(all(class(resCi)!='try-error'))
   			res$ci[,'lower'] = resCi$y
   }
 
@@ -168,7 +168,7 @@ profLlgm = function(fit,mc.cores=1, ...) {
         xout=res$breaks[Skeep], method='hyman'),
     silent=TRUE)
     
-    if(class(resCi)!='try-error')
+    if(all(class(resCi)!='try-error'))
       res$ci[,'upper']= resCi$y     
   }
 		
